@@ -6,13 +6,16 @@
 #' @references \url{http://ocrsdk.com/documentation/apireference/getApplicationInfo/}
 #' @references \url{http://ocrsdk.com/schema/appInfo-1.0.xsd}
 #' @usage getAppInfo()
+#' @examples \dontrun{
+#' getAppInfo()
+#' }
 
 getAppInfo <- function(){
 	app_id=getOption("AbbyyAppId"); app_pass=getOption("AbbyyAppPassword")
 	if(is.null(app_id) | is.null(app_pass)) stop("Please set application id and password using setapp(c('app_id', 'app_pass')).")
-	res <- httr::GET(paste0("http://",app_id,":",app_pass,"@cloud.ocrsdk.com/getApplicationInfo"))
-	httr::stop_for_status(res)
-	appinfo <- XML::xmlToList(httr::content(res))[[1]]
+	res <- GET("http://cloud.ocrsdk.com/getApplicationInfo", httr::authenticate(app_id, app_pass))
+	stop_for_status(res)
+	appinfo <- xmlToList(httr::content(res))[[1]]
 
 	cat("Name of Application: ", appinfo$name, "\n", sep = "")
   	cat("No. of Pages Remaining: ", appinfo$pages, "\n", sep = "")
@@ -21,3 +24,4 @@ getAppInfo <- function(){
   	cat("Type: ", appinfo$type, "\n", sep = "")
   	return(invisible(appinfo))
 }
+
