@@ -10,15 +10,18 @@
 #' @export
 #' @references \url{http://ocrsdk.com/documentation/apireference/getApplicationInfo/}
 #' @usage listTasks(fromDate=NULL,toDate=NULL,excludeDeleted='false')
+#' @examples \dontrun{
+#' listTasks(fromDate=NULL,toDate=NULL,excludeDeleted='false')
+#' }
 
 listTasks <- function(fromDate=NULL,toDate=NULL, excludeDeleted='false'){
 	app_id=getOption("AbbyyAppId"); app_pass=getOption("AbbyyAppPassword")
 	if(is.null(app_id) | is.null(app_pass)) stop("Please set application id and password using setapp(c('app_id', 'app_pass')).")
 	
 	querylist = list(fromDate = fromDate, toDate = toDate, excludeDeleted=excludeDeleted)
-	res <- httr::GET(paste0("http://",app_id,":",app_pass,"@cloud.ocrsdk.com/listTasks"), query=querylist)
-	httr::stop_for_status(res)
-	tasklist <- XML::xmlToList(httr::content(res))
+	res <- GET("http://cloud.ocrsdk.com/listTasks", httr::authenticate(app_id, app_pass), query=querylist)
+	stop_for_status(res)
+	tasklist <- xmlToList(httr::content(res))
 
 	if(is.null(tasklist)){
 		cat("No tasks in the application. \n")
