@@ -5,8 +5,9 @@
 #' @return Data frame with details of the task associated with the submitted MRZ document
 #' @export
 #' @references \url{http://ocrsdk.com/documentation/apireference/processMRZ/}
-#' @examples
-#' # processMRZ(file_path="file_path")
+#' @examples \dontrun{
+#' processMRZ(file_path="file_path")
+#' }
 
 processMRZ <- function(file_path=NULL){
 	app_id=getOption("AbbyyAppId"); app_pass=getOption("AbbyyAppPassword")
@@ -14,10 +15,10 @@ processMRZ <- function(file_path=NULL){
 	
 	if(is.null(file_path)) stop("Must specify file_path")
 
-	res <- httr::POST(paste0("http://",app_id,":",app_pass,"@cloud.ocrsdk.com/processMRZ"), body=httr::upload_file(file_path))
-	httr::stop_for_status(res)
-	tasklist <- XML::xmlToList(httr::content(res))
-	processdetails <- XML::xmlToList(httr::content(res))
+	res <- POST("http://cloud.ocrsdk.com/processMRZ", authenticate(app_id, app_pass), body=upload_file(file_path))
+	stop_for_status(res)
+	tasklist <- xmlToList(content(res))
+	processdetails <- xmlToList(content(res))
 	
 	resdf <- do.call(rbind.data.frame, processdetails) # collapse to a data.frame
 	names(resdf) <- names(processdetails[[1]])[1:length(resdf)] # names for the df, adjust for <7
