@@ -15,8 +15,9 @@
 #' @return Data frame with details of the task associated with the submitted Remote Image
 #' @export
 #' @references \url{http://ocrsdk.com/documentation/apireference/processRemoteImage/}
-#' @examples
-#' # processRemoteImage(img_url="img_url")
+#' @examples \dontrun{
+#' processRemoteImage(img_url="img_url")
+#' }
 
 processRemoteImage <- function(img_url=NULL, language="English", profile="documentConversion",textType="normal", imageSource="auto", correctOrientation="true", 
 						correctSkew="true",readBarcodes="false",exportFormat="txt", description=NULL, pdfPassword=NULL){
@@ -27,9 +28,9 @@ processRemoteImage <- function(img_url=NULL, language="English", profile="docume
 
 	querylist = list(source=img_url, language=language, profile=profile,textType=textType, imageSource=imageSource, correctOrientation=correctOrientation, 
 						correctSkew=correctSkew,readBarcodes=readBarcodes,exportFormat=exportFormat, description=description, pdfPassword=pdfPassword)
-	res <- httr::GET(paste0("http://",app_id,":",app_pass,"@cloud.ocrsdk.com/processRemoteImage"), query=querylist)
-	httr::stop_for_status(res)
-	processdetails <- XML::xmlToList(httr::content(res))
+	res <- GET("http://cloud.ocrsdk.com/processRemoteImage", authenticate(app_id, app_pass), query=querylist)
+	stop_for_status(res)
+	processdetails <- xmlToList(httr::content(res))
 	
 	resdf <- do.call(rbind.data.frame, processdetails) # collapse to a data.frame
 	names(resdf) <- names(processdetails[[1]])
